import fluxgen.command.install as install
import fluxgen.utils as utils


def main(args, parser, command, subparser):
    # This will raise an error if the member type (e.g., minicluster) is not known
    generator = install.FluxInstallScript()
    result = generator.render()

    # This is a preview only
    if args.dry_run:
        print(result)
        return

    print(f"Writing install script to {args.outfile}")

    # Write to file, and ensure is made executable
    utils.write_file(result, args.outfile, executable=True)



from fluxgen.template import Template

# Optional arguments (with defaults)
# I don't see the need to expose these (will do when there is reason)
# - mamba_prefix
# - python_version


class FluxInstallScript:
    required = []

    # Defaults
    # Optional:
    # mamba_prefix

    def __init__(self):
        """
        Create a new installl script.
        """
        self.template = Template("install-flux.sh")

    def render(self, **vars):
        """
        Render the variables into the template
        """
        return self.template.render(install_only=True)

    @classmethod
    def get_required(cls):
        return cls.required



import fluxgen.command.create as create
import fluxgen.utils as utils


def main(args, parser, command, subparser):
    # Assemble options we know are important
    options = {
        "lead-broker": args.lead_broker,
        "linkname": args.linkname,
        "command": command or None,
        "brokers": args.brokers,
        "subdomain": args.subdomain,
    }

    # This will raise an error if the member type (e.g., minicluster) is not known
    generator = create.FluxInstallScript()
    result = generator.render(**options)

    # This is a preview only
    if args.dry_run:
        print(result)
        return

    print(f"Writing install script to {args.outfile}")

    # Write to file, and ensure is made executable
    utils.write_file(result, args.outfile, executable=True)



import os

from setuptools import find_packages, setup  # noqa: H301

DESCRIPTION = "Helper tool to install and configure Flux Framework"

# Try to read description, otherwise fallback to short description
try:
    with open(os.path.abspath("README.md")) as filey:
        LONG_DESCRIPTION = filey.read()
except Exception:
    LONG_DESCRIPTION = DESCRIPTION

# Read in the version
# This is a bit janky I admit :)
with open(os.path.join("fluxgen", "__init__.py")) as fd:
    version = fd.read().strip().replace("__version__ = ", "").replace('"', "")

################################################################################
# MAIN #########################################################################
################################################################################

if __name__ == "__main__":
    setup(
        name="fluxgen",
        version=version,
        author="Vanessasaurus",
        author_email="vsoch@users.noreply.github.com",
        maintainer="Vanessasaurus",
        packages=find_packages(),
        include_package_data=True,
        zip_safe=False,
        url="https://github.com/converged-computing/fluxgen",
        license="MIT",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        long_description_content_type="text/markdown",
        keywords="multi-cluster, scheduler",
        setup_requires=["pytest-runner"],
        install_requires=[
            "Jinja2",
            "pyyaml",
        ],
        classifiers=[
            "Intended Audience :: Science/Research",
            "Intended Audience :: Developers",
            "License :: OSI Approved :: Apache Software License",
            "Programming Language :: C",
            "Programming Language :: Python",
            "Topic :: Software Development",
            "Topic :: Scientific/Engineering",
            "Operating System :: Unix",
            "Programming Language :: Python :: 3.11",
        ],
        entry_points={
            "console_scripts": [
                "fluxgen=fluxgen.client:run_fluxgen",
            ]
        },
    )
